Pulsanti comuni

Pulsanti comuni | TOC

Di seguito una breve descrizione di ogni pulsante.

| Testo grassetto.
| Testo corsivo.
| Testo sottolineato.
| Testo barrato.
| Allinea a sinistra.
| Allinea al centro.
| Allinea a destra.
| Giustifica.
| Lista non ordinata.
| Lista ordianta.
| Diminuisci l'indentazione.
| Aumenta l'indentazione.
| Annulla l'ultima operazione.
| Ripeti l'ultima operazione.
| Inserieci un nuovo collegamento, maggiori informazioni su questa funzione nella Sezione 'Inserisci un collegamento'
| Rimuovi tutti i collegamenti selezionati
| Inserisci una nuova àncora, maggiori informazioni su questa funzione nella Sezione 'Inserisci un'àncora'.
| Inserieci una nuova immagine, maggiori informazioni su questa funzione nella Sezione 'Inserisci una immagine'.
| Ripulisci il codice/rimuovi la formattazione non voluta. Questa funzione è utile quando si copia per esempio da un programma office
| Mostra questa guida
| Apre l'editor del sorgente HTML.
| Inserisce una nuova tabella 2x2 alla posizione corrente.
| Aggiunge una riga sopra quella corrente.
| Aggiunge una roga sotto quella corrente.
| Rimuove la riga corrente.
| Aggiunge una colonna prima di quella corrente.
| Aggiunge una colonna dopo quella corrente.
| Rimuove la colonna corrente.
| Inserisce una nuova riga orizzontale.
| Rimuove la formattazione dalla selezione.
| Formatta la selezione come pedice.
| Formatta la selezione come apice.

Vai a: Tavola dei contenuti | Su